==> WebCore-146.1.tar.gz: WebCore-146.1/kwq/KWQAccObject.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#import <Foundation/Foundation.h>

namespace DOM {
    class HTMLAreaElementImpl;
}

namespace khtml {
    class RenderObject;
}

@interface KWQAccObject : NSObject
{
    khtml::RenderObject* m_renderer;
    id m_data;
    DOM::HTMLAreaElementImpl* m_areaElement;
    NSMutableArray* m_children;
}

-(id)initWithRenderer:(khtml::RenderObject*)renderer;

-(BOOL)detached;
-(void)detach;

-(id)data;
-(void)setData:(id)data;

-(KWQAccObject*)firstChild;
-(KWQAccObject*)lastChild;
-(KWQAccObject*)previousSibling;
-(KWQAccObject*)nextSibling;
-(KWQAccObject*)parentObject;

-(void)childrenChanged;
-(void)clearChildren;

@end

==> WebCore-415.5.80.tar.gz: WebCore-415.5.80/kwq/KWQAccObject.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#import <Foundation/Foundation.h>
#import "KWQAccObjectCache.h"

namespace DOM {
    class HTMLAreaElementImpl;
}

namespace khtml {
    class RenderObject;
}

@interface KWQAccObject : NSObject
{
    khtml::RenderObject* m_renderer;
    id m_data;
    DOM::HTMLAreaElementImpl* m_areaElement;
    NSMutableArray* m_children;
    KWQAccObjectID m_accObjectID;
}

-(id)initWithRenderer:(khtml::RenderObject*)renderer;

-(BOOL)detached;
-(void)detach;

-(id)data;
-(void)setData:(id)data;

-(KWQAccObjectID)accObjectID;
-(void)setAccObjectID:(KWQAccObjectID) accObjectID;
-(void)removeAccObjectID;

-(KWQAccObject*)firstChild;
-(KWQAccObject*)lastChild;
-(KWQAccObject*)previousSibling;
-(KWQAccObject*)nextSibling;
-(KWQAccObject*)parentObject;

-(void)childrenChanged;
-(void)clearChildren;

@end
